@@ -175,30 +175,12 @@ def search_nyaasi(session, query):
         }
 
 
-def search_tenshi(session, query):
-    uwu.bypass_ddos_guard(session, TENSHI)
-    tenshi_page = session.get(TENSHI)
-    session_id = tenshi_page.cookies.get("tenshimoe_session")
-    token = (
-        htmlparser.fromstring(tenshi_page.text)
-        .xpath('//meta[@name="csrf-token"]')[0]
-        .get("content")
-    )
-
-    ajax_content = session.post(
-        TENSHI_URL_SEARCH_POST,
-        data={"q": query},
-        headers={
-            "x-requested-with": "XMLHttpRequest",
-            "x-csrf-token": token,
-            "referer": "https://tenshi.moe/",
-            "cookie": "tenshimoe_session={}".format(session_id),
-        },
-    )
-    results = ajax_content.json()
-
-    for result in results:
-        yield {"name": result.get("title"), "anime_url": result.get("url")}
+def search_tenshi(session, query, *, domain=TENSHI):
+    uwu.bypass_ddos_guard(session, domain)
+    tenshi_page = htmlparser.fromstring(session.get(domain + "anime", params={"q": query}).text)
+    
+    for result in tenshi_page.cssselect(".list > li > a"):
+        yield {"name": result.get("title"), "anime_url": result.get("href")}
 
 
 def search_zoro(session, query):
@@ -210,31 +192,15 @@ def search_zoro(session, query):
             "anime_url": ZORO + result.get("href")[1:-11],
         }
 
+def search_h_ntai_stream(session, query):
+    for result in htmlparser.fromstring(session.get(HENTAISTREAM, params={'s': query}).text).cssselect('article > .bsx > a'):
+        yield {
+            "name": result.get("title"),
+            "anime_url": result.get("href"),
+        }
 
 def search_haho(session, query):
-
-    haho_page = session.get(HAHO)
-    session_id = haho_page.cookies.get("hentai_aho_streaming_session")
-    token = (
-        htmlparser.fromstring(haho_page.text)
-        .xpath('//meta[@name="csrf-token"]')[0]
-        .get("content")
-    )
-
-    ajax_content = session.post(
-        HAHO_URL_SEARCH_POST,
-        data={"q": query},
-        headers={
-            "x-requested-with": "XMLHttpRequest",
-            "x-csrf-token": token,
-            "referer": "https://haho.moe/",
-            "cookie": "hentai_aho_streaming_session={}".format(session_id),
-        },
-    )
-    results = ajax_content.json()
-
-    for result in results:
-        yield {"name": result.get("title"), "anime_url": result.get("url")}
+    yield from search_tenshi(session, query, domain=HAHO)
 
 
 link = {
@@ -248,6 +214,7 @@ link = {
     "kawaiifu": search_kawaiifu,
     "gogoanime": search_gogoanime,
     "haho": search_haho,
+    "hentaistream": search_h_ntai_stream,
     "tenshi": search_tenshi,
     "nyaa": search_nyaasi,
     "twist": search_twist,
